@@ -1,5 +1,5 @@
 /*
- *	NEWS - GTK-based RSS Ticker - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -459,9 +459,9 @@ int get_http_status_code(const char *response)
 	int	i = 0;
 
 	while (response[i] != ' ' && response[i] != TAB) {
-		if (response[i] == '\n' || response[i] == '\r' || response[i] == '\0') {
+		if (response[i] == '\n' || response[i] == '\r' || response[i] == '\0')
 			return -1;
-		} else
+		else
 			i++;
 	}
 	while (response[i] == ' ' || response[i] == TAB)
@@ -661,6 +661,9 @@ SOCKET connect_to_host(const char *host, const char *portnum_str)
 	memset(&hints, 0, sizeof(hints));
 	hints.ai_family = AF_UNSPEC;
 	hints.ai_socktype = SOCK_STREAM;
+/*#ifdef VERBOSE_OUTPUT
+	fprintf(STD_OUT, "Resolving %s ... ", host);
+#endif*/
 	if ((i = getaddrinfo(host, portnum_str, &hints, &server_info)) != 0) {
 		if (get_use_proxy() || get_ticker_env()->selection_mode == SINGLE) {
 #ifndef G_OS_WIN32
@@ -681,6 +684,9 @@ SOCKET connect_to_host(const char *host, const char *portnum_str)
 		}
 		return -1;
 	}
+/*#ifdef VERBOSE_OUTPUT
+	fprintf(STD_OUT, "Done\n");
+#endif*/
 	/* we get a list */
 	for (ptr = server_info; ptr != NULL; ptr = ptr->ai_next) {
 		/* create socket */
