@@ -1,5 +1,5 @@
 /*
- *	NEWS - GTK-based RSS Ticker - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -632,10 +632,17 @@ static int compute_surface_and_win()
 }
 
 /*
- * timeout handler to render one part of cairo image surface onto drawing area
- * image is shifted to the left by <shift_size> pixels
+ * timeout handler to render one part of cairo image surface onto drawing
+ * area - image is shifted to left by <shift_size> pixels
  *
- * handler 'listens' to suspend_rq, reload_rq and compute_rq
+ * handler 'listens' to flags: suspend_rq, reload_rq, compute_rq and
+ * stream_fully_read
+ *
+ * notes:
+ * - reload_rq may be a misleading name as, in multiple selection mode,
+ * we will load next stream, not reload the same one
+ * - stream_fully_read is only relevant in multiple selection mode because
+ * there is no need to reload each time in single selection mode
  */
 static gint shift2left_callback()
 {
@@ -647,7 +654,9 @@ static gint shift2left_callback()
 	if (env->suspend_rq)
 		return TRUE;	/* does nothing - just return */
 	else if ((shift_counter * prm->shift_size < env->surf_width - env->drwa_width - 8) &&\
+			/*!(env->selection_mode == MULTIPLE && env->stream_fully_read) &&\*/
 			!env->reload_rq && !env->compute_rq) {
+		env->suspend_rq = TRUE;
 		/*
 		 * draw onto ticker area
 		 * (we now use cairo instead of deprecated gdk_draw_ stuff)
@@ -670,19 +679,20 @@ static gint shift2left_callback()
 		cairo_destroy(cr);
 		/* we're done */
 		gdk_window_end_paint(env->drw_a->window);
+		env->suspend_rq = FALSE;
 		/*
 		 * speeding up/down on the fly
 		 */
 		if (speed_up_flag == TRUE || speed_down_flag == TRUE) {
 			if (speed_up_flag == TRUE) {
 				speed_up_flag = FALSE;
-				if (prm-> delay > 1)
+				if (prm->delay > 1)
 					prm->delay--;
 				else
 					return TRUE;
 			} else if (speed_down_flag == TRUE) {
 				speed_down_flag = FALSE;
-				if (prm-> delay < 50)
+				if (prm->delay < 50)
 					prm->delay++;
 				else
 					return TRUE;
@@ -706,23 +716,25 @@ static gint shift2left_callback()
     			if (env->selection_mode == SINGLE && env->reload_rq)
 				load_resource(resrc, NULL);
 			else {
-				while ((i = load_resource(resrc, get_selected_url_list())) != OK)
+				while ((i = load_resource(resrc, get_selected_url_list())) != OK) {
 					if (i == CONNECT_TOO_MANY_ERRORS && env->selection_mode == MULTIPLE) {
 						if (get_params()->disable_popups == 'n') {
-							snprintf(tmp, 256, "\nFailed to connect %d times in a row.\n\n"
-								"Please check your internet connection and/or "
-								"your connection settings.\n\n"
-								"Switch to single selection mode ?\n",
-								CONNECT_FAIL_MAX);
+							snprintf(tmp, 256,
+							"\nFailed to connect %d times in a row.\n\n"
+							"Please check your internet connection and/or "
+							"your connection settings.\n\n"
+							"Switch to single selection mode ?\n",
+							CONNECT_FAIL_MAX);
 							if (question_win(tmp) == YES) {
 								env->selection_mode = SINGLE;
 								break;
 							}
 						} else {
-							fprintf(STD_ERR, "Failed to connect %d times in a row\n"
-								"Please check your internet connection and/or "
-								"your connection settings\n",
-								CONNECT_FAIL_MAX);
+							fprintf(STD_ERR,
+							"Failed to connect %d times in a row\n"
+							"Please check your internet connection and/or "
+							"your connection settings\n",
+							CONNECT_FAIL_MAX);
 							/* TODO: improve that */
 							if (gtk_events_pending()) {
 								if (gtk_main_iteration_do(FALSE))
@@ -735,6 +747,7 @@ static gint shift2left_callback()
 #endif
 						}
 					}
+				}
 			}
 			check_time_load_resource(TIME_RESET);
 		}
@@ -822,6 +835,11 @@ static void print_help()
 	fprintf(STD_OUT, "\n");
 }
 
+static void print_version()
+{
+	fprintf(STD_OUT, APP_NAME" version "APP_VERSION_NUMBER"\n");
+}
+
 static void print_license()
 {
 	int	i;
@@ -849,6 +867,25 @@ gint update_everything()
 		return TRUE;
 }
 
+#ifdef G_OS_WIN32
+/* this is meant to be used with the new gtk runtime */
+static int init_win32_mmtimer()
+{
+	TIMECAPS	tc;
+	MMRESULT	mmr;
+	unsigned	int highest_res;
+
+	mmr = timeGetDevCaps(&tc, sizeof(TIMECAPS));
+	highest_res = tc.wPeriodMin;
+	if (timeBeginPeriod(highest_res) == TIMERR_NOERROR)
+		return 0;
+	else {
+		fprintf(STD_ERR, "init_win32_mmtimer() error");
+		return -1;
+	}
+}
+#endif
+
 int main(int argc, char *argv[])
 {
 	GdkPixbuf	*pixb = NULL;
@@ -868,16 +905,6 @@ int main(int argc, char *argv[])
 # error Libxml2: tree support not compiled in
 #endif
 	xmlInitParser();
-#ifdef G_OS_WIN32
-	if ((i = WSAStartup(MAKEWORD(2, 2), &wsadata)) != 0) {
-		fprintf(STD_ERR, "WSAStartup() error %d\n", i);
-		return WIN32V_ERROR;
-	} else if (LOBYTE(wsadata.wVersion) != 2 || HIBYTE(wsadata.wVersion) != 2) {
-		fprintf(STD_ERR, "Couldn't find a usable version of Winsock.dll\n");
-		WSACleanup();
-		return WIN32V_ERROR;
-	}
-#endif
 	env = malloc2(sizeof(TickerEnv));
 	resrc = malloc2(sizeof(Resource));
 	prm = malloc2(sizeof(Params));
@@ -902,10 +929,20 @@ int main(int argc, char *argv[])
 	g_signal_connect(G_OBJECT(env->win), "destroy", G_CALLBACK(gtk_widget_destroy), &(env->win));
 
 #ifdef G_OS_WIN32
+	if ((i = WSAStartup(MAKEWORD(2, 2), &wsadata)) != 0)
+		big_error(WIN32V_ERROR, "WSAStartup() error ", itoa2(i), "", "");
+	else if (LOBYTE(wsadata.wVersion) != 2 || HIBYTE(wsadata.wVersion) != 2) {
+		WSACleanup();
+		big_error(WIN32V_ERROR, "Couldn't find a usable version of Winsock.dll", "", "", "");
+	}
 	if (get_progfiles_dir() == NULL)
 		big_error(WIN32V_ERROR, "Can't find Program Files directory", "", "", "");
 	else if (get_appdata_dir() == NULL)
 		big_error(WIN32V_ERROR, "Can't find Application Data directory", "", "", "");
+	if (init_win32_mmtimer() != 0)
+		if (question_win("Can't initialize win32 multimedia timer. "
+				"Scrolling may be very slow. Continue ?") == NO)
+			exit(WIN32V_ERROR);
 #endif
 	/*
 	 * create news dir in user home dir if it doesn't exist
@@ -918,12 +955,15 @@ int main(int argc, char *argv[])
 	/*
 	 * get help, show license, set instance id or check available system fonts
 	 */
-	if (argc >= 2 && (strcmp(argv[1], "-help") == 0 || strcmp(argv[1], "--help") == 0 || \
+	if (argc >= 2 && (strcmp(argv[1], "-help") == 0 || strcmp(argv[1], "--help") == 0 ||\
 			strcmp(argv[1], "-h") == 0 || strcmp(argv[1], "-?") == 0)) {
 		print_help();
 		return 0;
-	} else if (argc >= 2 && (strcmp(argv[1], "-license") == 0 || \
-			strcmp(argv[1], "--license") == 0)) {
+	} else if (argc >= 2 && (strcmp(argv[1], "-version") == 0 || strcmp(argv[1], "--version") == 0 ||\
+			strcmp(argv[1], "-v") == 0)) {
+		print_version();
+		return 0;
+	} else if (argc >= 2 && (strcmp(argv[1], "-license") == 0 || strcmp(argv[1], "--license") == 0)) {
 		print_license();
 		return 0;
 	} else if (argc >= 2 && strncmp(argv[1], "-instance-id=", strlen("-instance-id=")) == 0) {
@@ -931,8 +971,7 @@ int main(int argc, char *argv[])
 			fprintf(STD_ERR, "Instance ID invalid value: %d\n", instance_id);
 			instance_id = 0;
 		}
-	} else if (argc >= 2 && (strcmp(argv[1], "-dumpfontlist") == 0 || \
-			strcmp(argv[1], "--dumpfontlist") == 0)) {
+	} else if (argc >= 2 && (strcmp(argv[1], "-dumpfontlist") == 0 || strcmp(argv[1], "--dumpfontlist") == 0)) {
 		dump_font_list();
 		return 0;
 	}
@@ -1024,9 +1063,14 @@ int main(int argc, char *argv[])
 	if (n_resources == 0 && env->selection_mode == MULTIPLE && i == OK && j == OK)
 		fprintf(STD_OUT, "Will use feed selection\n");
 	else {
-		if (env->selection_mode == MULTIPLE && (i != OK || j != OK))
-			warning("No feed selection available", "-",
+		if (env->selection_mode == MULTIPLE && (i != OK || j != OK)) {
+			if (j == SELECTION_EMPTY)
+				warning("No feed selected", "-",
 					"Switching to single selection mode", "", TRUE);
+			else if (j == SELECTION_ERROR)
+				warning("No feed selection available", "-",
+					"Switching to single selection mode", "", TRUE);
+		}
 		env->selection_mode = SINGLE;
 		if (n_resources == 0) {
 			if (prm->homefeed[0] != '\0') {
