@@ -1,5 +1,5 @@
 /*
- *	NEWS - GTK-based RSS Ticker - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
+ *	TICKR - GTK-based Feed Reader - Copyright (C) Emmanuel Thomas-Maurin 2009-2011
  *	<manutm007@gmail.com>
  *
  * 	This program is free software: you can redistribute it and/or modify
@@ -330,12 +330,10 @@ void info_win(const char *title, const char *txt, info_type info, gboolean selec
 	if (info == INFO) {
 		/* better without any image if info only so do nothing here */
 		/*image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);*/
-	}
-	else if (info == INFO_WARNING) {
+	} else if (info == INFO_WARNING) {
 		image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
 		gtk_table_attach_defaults(GTK_TABLE(table), image, 0, 1, 0, 1);
-	}
-	else if (info == INFO_ERROR) {
+	} else if (info == INFO_ERROR) {
 		image = gtk_image_new_from_stock(GTK_STOCK_DIALOG_ERROR, GTK_ICON_SIZE_DIALOG);
 		gtk_table_attach_defaults(GTK_TABLE(table), image, 0, 1, 0, 1);
 	}
@@ -348,7 +346,7 @@ void info_win(const char *title, const char *txt, info_type info, gboolean selec
 	if (info == INFO) {
 		if (layout_width > get_ticker_env()->screen_w - 60)
 			gtk_widget_set_size_request(label[0], get_ticker_env()->screen_w - 60, -1);
-	} else{
+	} else {
 		if (layout_width > get_ticker_env()->screen_w - 120)	/* extra 60 for image width */
 			gtk_widget_set_size_request(label[0], get_ticker_env()->screen_w - 120, -1);
 	}
